@@ -6,6 +6,8 @@ use Exception::Base;
 
 assert_raises qr/test/, sub { die 'test'; }, 'regexp';
 
-assert_raises 'Exception::Base', sub { Exception::Base->throw; }, 'string';
+assert_raises {message => 'test'}, sub { Exception::Base->throw( message => 'test' ); }, 'string';
 
 assert_raises ['NoSuchClass', 'Exception::Base', 'AnotherClass'], sub { Exception::Base->throw; }, 'arrayref';
+
+print "OK\n";
