@@ -19,12 +19,11 @@ BEGIN {
 }
 
 use Test::Unit::Lite 0.10;
+use Test::Assert;
 
-use Exception::Base
-    max_arg_nums => 0, max_arg_len => 200, verbosity => 4;
-use Exception::Warning '%SIG' => 'die';
-use Exception::Died    '%SIG';
-use Exception::Assertion
-    verbosity => 4;
+use Exception::Base max_arg_nums => 0, max_arg_len => 200, verbosity => 4;
+use Exception::Warning '%SIG' => 'die', verbosity => 4;
+use Exception::Died '%SIG', verbosity => 4;
+use Exception::Assertion verbosity => 4;
 
 all_tests;
